@@ -1,11 +1,11 @@
 import sympy as sy
 import IPython
 
-
+global DatosList,Orden
 DatosList = []
 Orden = 8
 
-def InitSystem():
+def Inicializar():
   global DatosList,Orden
   DatosList = []
   Orden = 8
